@@ -5,7 +5,7 @@
  *
  * GnuPG is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GnuPG is distributed in the hope that it will be useful,
@@ -14,9 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
- * USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  *
  * According to the definition of DES in FIPS PUB 46-2 from December 1993.
@@ -106,7 +104,7 @@
  *
  *     if ( (error_msg = selftest()) )
  *     {
- *	   fprintf(stderr, "An error in the DES/Tripple-DES implementation occured: %s\n", error_msg);
+ *	   fprintf(stderr, "An error in the DES/Tripple-DES implementation occurred: %s\n", error_msg);
  *	   abort();
  *     }
  */
@@ -431,15 +429,15 @@ static byte weak_keys[64][8] =
 /*
  * Macros to convert 8 bytes from/to 32bit words.
  */
-#define READ_64BIT_DATA(data, left, right)					\
-    left  = (data[0] << 24) | (data[1] << 16) | (data[2] << 8) | data[3];	\
-    right = (data[4] << 24) | (data[5] << 16) | (data[6] << 8) | data[7];
+#define READ_64BIT_DATA(data, left, right)				     \
+  left  = ((u32)data[0] << 24) | (data[1] << 16) | (data[2] << 8) | data[3]; \
+  right = ((u32)data[4] << 24) | (data[5] << 16) | (data[6] << 8) | data[7];
 
-#define WRITE_64BIT_DATA(data, left, right)					\
-    data[0] = (left >> 24) &0xff; data[1] = (left >> 16) &0xff; 		\
-    data[2] = (left >> 8) &0xff; data[3] = left &0xff;				\
-    data[4] = (right >> 24) &0xff; data[5] = (right >> 16) &0xff;		\
-    data[6] = (right >> 8) &0xff; data[7] = right &0xff;
+#define WRITE_64BIT_DATA(data, left, right)				\
+  data[0] = (left >> 24) &0xff; data[1] = (left >> 16) &0xff; 		\
+  data[2] = (left >> 8) &0xff; data[3] = left &0xff;			\
+  data[4] = (right >> 24) &0xff; data[5] = (right >> 16) &0xff;		\
+  data[6] = (right >> 8) &0xff; data[7] = right &0xff;
 
 /*
  * Handy macros for encryption and decryption of data
@@ -454,7 +452,7 @@ static void
 burn_stack (int bytes)
 {
     char buf[64];
-    
+
     wipememory(buf,sizeof buf);
     bytes -= sizeof buf;
     if (bytes > 0)
@@ -962,7 +960,7 @@ do_tripledes_setkey ( void *ctx, const byte *key, unsigned keylen )
         burn_stack (64);
 	return G10ERR_WEAK_KEY;
     }
-    burn_stack (64); 
+    burn_stack (64);
 
     return 0;
 }
