@@ -1,6 +1,6 @@
 /* gpgv.c - The GnuPG signature verify utility
  * Copyright (C) 1998, 1999, 2000, 2001, 2002, 2005, 2006,
- *               2009 Free Software Foundation, Inc.
+ *               2009, 2012 Free Software Foundation, Inc.
  *
  * This file is part of GnuPG.
  *
@@ -56,10 +56,11 @@ enum cmd_and_opt_values { aNull = 0,
     oVerbose	  = 'v',
     oBatch	  = 500,
     oKeyring,
-    oIgnoreTimeConflict,                      
+    oIgnoreTimeConflict,
     oStatusFD,
     oLoggerFD,
     oHomedir,
+    oWeakDigest,
 aTest };
 
 
@@ -70,11 +71,12 @@ static ARGPARSE_OPTS opts[] = {
     { oVerbose, "verbose",   0, N_("verbose") },
     { oQuiet,	"quiet",     0, N_("be somewhat more quiet") },
     { oKeyring, "keyring"   ,2, N_("take the keys from this keyring")},
-    { oIgnoreTimeConflict, "ignore-time-conflict", 0, 
+    { oIgnoreTimeConflict, "ignore-time-conflict", 0,
                            N_("make timestamp conflicts only a warning") },
     { oStatusFD, "status-fd" ,1, N_("|FD|write status info to this FD") },
     { oLoggerFD, "logger-fd",1, "@" },
     { oHomedir, "homedir", 2, "@" },   /* defaults to "~/.gnupg" */
+    { oWeakDigest, "weak-digest", 2, "@" },   /* defaults to "~/.gnupg" */
 
 {0} };
 
@@ -142,16 +144,20 @@ main( int argc, char **argv )
     opt.pgp2_workarounds = 1;
     opt.keyserver_options.options|=KEYSERVER_AUTO_KEY_RETRIEVE;
     opt.trust_model = TM_ALWAYS;
+    opt.no_sig_cache = 1;
+    opt.flags.require_cross_cert = 1;
     opt.batch = 1;
+    opt.weak_digests = NULL;
 
     opt.homedir = default_homedir ();
 
     tty_no_terminal(1);
     tty_batchmode(1);
-    disable_dotlock();
+    dotlock_disable ();
 
     set_native_charset (NULL); /* Try to auto set the character set */
-    
+    additional_weak_digest("MD5");
+
     pargs.argc = &argc;
     pargs.argv = &argv;
     pargs.flags=  1;  /* do not remove the args */
@@ -164,6 +170,7 @@ main( int argc, char **argv )
 	  case oStatusFD: set_status_fd( pargs.r.ret_int ); break;
 	  case oLoggerFD: log_set_logfile( NULL, pargs.r.ret_int ); break;
 	  case oHomedir: opt.homedir = pargs.r.ret_str; break;
+	  case oWeakDigest: additional_weak_digest(pargs.r.ret_str); break;
 	  case oIgnoreTimeConflict: opt.ignore_time_conflict = 1; break;
 	  default : pargs.err = 2; break;
 	}
@@ -181,9 +188,9 @@ main( int argc, char **argv )
         keydb_add_resource ("trustedkeys" EXTSEP_S "gpg", 8, 0);
     for(sl = nrings; sl; sl = sl->next )
         keydb_add_resource (sl->d, 8, 0 );
-    
+
     FREE_STRLIST(nrings);
-    
+
     if( (rc = verify_signatures( argc, argv ) ))
         log_error("verify signatures failed: %s\n", g10_errstr(rc) );
 
@@ -203,7 +210,7 @@ g10_exit( int rc )
 
 
 /* Stub:
- * We have to override the trustcheck from pkclist.c becuase 
+ * We have to override the trustcheck from pkclist.c becuase
  * this utility assumes that all keys in the keyring are trustworthy
  */
 int
@@ -214,9 +221,10 @@ check_signatures_trust( PKT_signature *sig )
 
 void
 read_trust_options(byte *trust_model,ulong *created,ulong *nextcheck,
-		   byte *marginals,byte *completes,byte *cert_depth) {}
+		   byte *marginals,byte *completes,byte *cert_depth,
+		   byte *min_cert_level) {}
 
-/* Stub: 
+/* Stub:
  * We don't have the trustdb , so we have to provide some stub functions
  * instead
  */
@@ -336,7 +344,7 @@ check_secret_key( PKT_secret_key *sk, int n )
 }
 
 /* Stub:
- * No secret key, so no passphrase needed 
+ * No secret key, so no passphrase needed
  */
 DEK *
 passphrase_to_dek( u32 *keyid, int pubkey_algo,
@@ -388,6 +396,7 @@ void cipher_sync( CIPHER_HANDLE c ) {}
 void random_dump_stats(void) {}
 int quick_random_gen( int onoff ) { return -1;}
 void randomize_buffer( byte *buffer, size_t length, int level ) {}
+void randomize_mpi (MPI mpi, size_t nbits, int level) {}
 int random_is_faked() { return -1;}
 byte *get_random_bits( size_t nbits, int level, int secure ) { return NULL;}
 void set_random_seed_file( const char *name ) {}
@@ -425,12 +434,15 @@ void init_ttyfp (void) { }
 #ifdef HAVE_LIBREADLINE
 void tty_enable_completion(rl_completion_func_t *completer) {}
 void tty_disable_completion(void) {}
+void rl_cleanup_after_signal (void) {}
+void rl_free_line_state (void) {}
 #endif
 
 /* We do not do any locking, so use these stubs here */
-void disable_dotlock(void) {}
-DOTLOCK create_dotlock( const char *file_to_lock ) { return NULL; }
-void destroy_dotlock (DOTLOCK h) {}
-int make_dotlock( DOTLOCK h, long timeout ) { return 0;}
-int release_dotlock( DOTLOCK h ) {return 0;}
-void remove_lockfiles(void) {}
+void dotlock_disable(void) {}
+dotlock_t dotlock_create (const char *file_to_lock, unsigned int flags)
+{ return NULL; }
+void dotlock_destroy (dotlock_t h, int reclaim) {}
+int dotlock_take (dotlock_t h, long timeout) { return 0;}
+int dotlock_release (dotlock_t h) {return 0;}
+void dotlock_remove_lockfiles (int reclaim) {}
